@@ -113,6 +113,11 @@ class TestSlugification(unittest.TestCase):
         r = slugify(txt, stopwords=['stopword'])
         self.assertEqual(r, 'this-has-a')
 
+    def test_stopword_removal_casesensitive(self):
+        txt = 'thIs Has a stopword Stopword'
+        r = slugify(txt, stopwords=['Stopword'], lowercase=False)
+        self.assertEqual(r, 'thIs-Has-a-stopword')
+
     def test_multiple_stopword_occurances(self):
         txt = 'the quick brown fox jumps over the lazy dog'
         r = slugify(txt, stopwords=['the'])
@@ -184,6 +189,15 @@ class TestSlugification(unittest.TestCase):
         r = slugify(txt, separator='_', regex_pattern=regex_pattern)
         self.assertNotEqual(r, "_this_is_a_test_")
 
+    def test_replacements(self):
+        txt = '10 | 20 %'
+        r = slugify(txt, replacements=[['|', 'or'], ['%', 'percent']])
+        self.assertEqual(r, "10-or-20-percent")
+
+        txt = 'I ♥ 🦄'
+        r = slugify(txt, replacements=[['♥', 'amour'], ['🦄', 'licorne']])
+        self.assertEqual(r, "i-amour-licorne")
+
 
 class TestUtils(unittest.TestCase):
 
